routes

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 25, 2019 License: Apache-2.0 Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AwsAccountsFromUserIDByAccountID

func AwsAccountsFromUserIDByAccountID(db models.XODB, userID int, accountIDs []int) ([]aws.AwsAccount, error)

AwsAccountsFromUserIDByAccountID retrieves rows from 'trackit.aws_account' as AwsAccount. The result is filtered by a slice of accountID

func DeleteAwsAccountFromAccountID

func DeleteAwsAccountFromAccountID(db models.XODB, userID int, accountID int) (int, error)

DeleteAwsAccountFromAccountID delete an AWS account based on the accountID passed to it. It does not perform any check, especially on authorizations, which needs to be done by the caller

Types

type BillRepositoryUpdateInfo

type BillRepositoryUpdateInfo struct {
	BillRepositoryId int        `json:"billRepositoryId"`
	AwsAccountPretty string     `json:"awsAccountPretty"`
	AwsAccountId     int        `json:"awsAccountId"`
	Bucket           string     `json:"bucket"`
	Prefix           string     `json:"prefix"`
	NextStarted      *time.Time `json:"nextStarted"`
	NextPending      *bool      `json:"nextPending"`
	LastStarted      *time.Time `json:"lastStarted"`
	LastFinished     *time.Time `json:"lastFinished"`
	LastError        *string    `json:"lastError"`
}

func BillRepositoryUpdates

func BillRepositoryUpdates(db dbAccessor, userId int) ([]BillRepositoryUpdateInfo, error)

Jump to